@@ -21,12 +21,16 @@
 #ifndef KMIXWINDOW_H
 #define KMIXWINDOW_H
 
+// Qt
+#include <qpointer.h>
+
 // KDE
 #include <kxmlguiwindow.h>
 
 // KMix
 #include "core/ControlManager.h"
 #include "gui/kmixprefdlg.h"
+#include "kmixapp.h"
 
 
 class QTabWidget;
@@ -45,13 +49,12 @@ class KMixWindow : public KXmlGuiWindow
    Q_OBJECT
 
 public:
-   KMixWindow(bool invisible, bool reset);
+   KMixWindow(KMixApp::StartupOptions startupOptions);
    virtual ~KMixWindow();
 
 private:
    void saveBaseConfig();
    void saveViewConfig();
-   void loadAndInitConfig(bool reset);
    void loadBaseConfig();
 
    void initPrefDlg();
@@ -63,11 +66,10 @@ private:
    void fixConfigAfterRead();
 
 protected:
-   bool queryClose() override;
+    void closeEvent(QCloseEvent *ev) override;
 
 public Q_SLOTS:
    void controlsChange(ControlManager::ChangeType changeType);
-   void quit();
    void showSettings();
    void showHelp();
    void showAbout();
@@ -89,14 +91,14 @@ private:
     void forkExec(const QStringList& args);
     KToggleAction* _actionShowMenubar;
 
-   bool m_startVisible;
-   bool m_visibilityUpdateAllowed;
-   bool m_autouseMultimediaKeys;   // Due to message freeze, not in config dialog in KDE4.4
+    bool m_startVisible;
+    bool m_autouseMultimediaKeys;   // Due to message freeze, not in config dialog in KDE4.4
+    bool m_noDockWidget;
 
    QTabWidget *m_wsMixers;
 
    KMixDockWidget *m_dockWidget;
-   DialogSelectMaster *m_dsm;
+   QPointer<DialogSelectMaster> m_masterSelectDialog;
 
    QString m_defaultCardOnStart;
    bool m_dontSetDefaultCardOnStart;
@@ -112,6 +114,7 @@ private:
     bool updateDocking();
     void removeDock();
     void updateTabsClosable();
+    bool shouldShowDock() const;
 
 private:
     static QString getKmixctrlRcFilename(const QString &postfix);
@@ -123,11 +126,9 @@ private Q_SLOTS:
    void plugged(const char *driverName, const QString &udi, int dev);
    void unplugged(const QString &udi);
 
-   void hideOrClose();
    void slotIncreaseVolume();
    void slotDecreaseVolume();
    void slotMute();
-   void slotSelectMasterClose(QObject*);
 
    void newView();
    void saveAndCloseView(int);
