@@ -21,7 +21,7 @@
 
 #include "core/mixdevice.h"
 
-#include <qregexp.h>
+#include <qregularexpression.h>
 
 #include <klocalizedstring.h>
 
@@ -99,13 +99,13 @@ static const QString channelTypeToIconName( MixDevice::ChannelType type )
  * The ChannelType tells which kind of control the MixDevice is.
  */
 MixDevice::MixDevice(  Mixer* mixer, const QString& id, const QString& name, ChannelType type )
-    : _profControl(0)
+    : _profControl(nullptr)
 {
     init(mixer, id, name, channelTypeToIconName(type), nullptr);
 }
 
 MixDevice::MixDevice(  Mixer* mixer, const QString& id, const QString& name, const QString& iconName, MixSet* moveDestinationMixSet )
-    : _profControl(0)
+    : _profControl(nullptr)
 {
     init(mixer, id, name, iconName, moveDestinationMixSet);
 }
@@ -270,7 +270,7 @@ void MixDevice::setEnumId(int enumId)
 const QString MixDevice::dbusPath() const
 {
    QString controlPath = _id;
-   controlPath.replace(QRegExp("[^a-zA-Z0-9_]"), "_");
+   controlPath.replace(QRegularExpression("[^a-zA-Z0-9_]"), "_");
    controlPath.replace(QLatin1String("//"), QLatin1String("/"));
 
    if ( controlPath.endsWith( '/' ) )
